@@ -3,7 +3,7 @@
 #' @import data.table
 #' @import antaresRead
 #' @importFrom methods is
-#' @importFrom stats median quantile sd
+#' @importFrom stats median quantile sd as.formula
 
 .onLoad <- function(libname, pkgname){
   setAlias(
@@ -12,68 +12,68 @@
     c("areas", "links", "H. ROR", "WIND", "SOLAR", "MISC. NDG", "LOAD", "BALANCE",
       "ROW BAL.", "linkCapacity", "mustRun")
   )
-  
+
   setAlias(
     "upwardMargin",
     "Data required by 'addUpwardMargin()'",
     c("areas", "links", "H. ROR", "WIND", "SOLAR", "MISC. NDG", "LOAD", "BALANCE",
       "ROW BAL.", "AVL DTG", "linkCapacity", "hydroStorageMaxPower")
   )
-  
+
   setAlias(
     "exportsImports",
     "Data required by 'addExportAndImport()'",
     c("areas", "links", "FLOW LIN.", "linkCapacity")
   )
-  
+
   setAlias(
     "loadFactorLink",
     "Data required by 'addLoadFactorLink()'",
     c("links", "FLOW LIN.", "linkCapacity")
   )
-  
+
   setAlias(
     "externalDependency",
     "Data required by 'externalDependency()'",
     c("areas", "links", "LOAD", "ROW BAL.", "PSP", "MISC. NDG", "H. ROR", "WIND",
       "SOLAR", "AVL DTG", "FLOW LIN.", "mustRun", "linkCapacity", "hydroStorageMaxPower")
   )
-  
+
   setAlias(
     "loadFactor",
     "Data required by 'loadFactor()'",
-    c("clusters", "thermalModulation", "mcYears")
+    c("clusters", "thermalModulation", "mcYears", "thermalAvailabilities")
   )
-  
+
   setAlias(
     "modulation",
     "Data required by 'modulation()'",
     c("areas", "clusters", "mcYears", "NUCLEAR", "LIGNITE", "COAL", "GAS", "OIL", "MIX. FUEL",
       "MISC. DTG", "H. STOR", "H. ROR", "SOLAR", "WIND")
   )
-  
+
   setAlias(
     "netLoadRamp",
     "Data required by function 'netLoadRamp()'",
     c("areas", "mcYears","LOAD", "ROW BAL.", "PSP", "MISC. NDG", "H. ROR", "WIND",
       "SOLAR", "BALANCE", "mustRun")
   )
-  
+
   setAlias(
     "surplus",
     "Data required by function 'surplus()'",
-    c("areas", "links", "mcYears", "LOAD", "MRG. PRICE", "OV. COST",
+    c("areas", "links", "mcYears", "LOAD", "MRG. PRICE", "OP. COST",
       "CONG. FEE (ALG.)", "NUCLEAR", "LIGNITE", "COAL", "GAS", "OIL", "MIX. FUEL",
       "MISC. DTG", "H. STOR", "H. ROR", "WIND", "SOLAR", "MISC. NDG", "PSP",
       "ROW BAL.")
   )
-  
+
   setAlias(
     "surplusClusters",
     "Data required by 'surplusClusters()'",
     c("areas", "clusters", "mcYears", "MRG. PRICE")
   )
-  
+
   setAlias(
     "surplusSectors",
     "Data required by function 'surplusSectors()'",
@@ -100,7 +100,8 @@ globalVariables(
     "surplusPerUnit", "thermalPmin", "timeId", "to", "toDistrict",
     "totalSurplus", "transCapacityDirect", "transCapacityIndirect",
     "unitcount", "upwardModulation", "variableCost",
-    "interconnectedDownwardMargin", "interconnectedUpwardMargin"
+    "interconnectedDownwardMargin", "interconnectedUpwardMargin",
+    "thermalAvailability", "OP. COST"
   )
 )
 
